@@ -291,7 +291,7 @@ COMMANDS = {
         "type": "QUERY",
         "response": [["string", "Protocol Version", ""]],
         "test_responses": [
-            b"",
+            b"^D00518;\x03\r",
         ],
     },
     # SETTER ###
@@ -313,7 +313,7 @@ COMMANDS = {
     "POP": {
         "name": "POP",
         "prefix": "^S007",
-        "description": "Set output souce priority 				(Maunal Option 01)",
+        "description": "Set output souce priority 				(Manual Option 01)",
         "help": " -- example: POP0 		(set Output POP0 [0: Solar-Utility-Batter],  POP1 [1: Solar-Battery-Utility]",
         "type": "SETTER",
         "response": [
@@ -328,7 +328,7 @@ COMMANDS = {
     "PSP": {
         "name": "PSP",
         "prefix": "^S007",
-        "description": "Set solar power priority 				(Maunal Option 05)",
+        "description": "Set solar power priority 				(Manual Option 05)",
         "help": " -- example: PSP0 		(set Priority PSP0 [0: Battery-Load-Utiliy (+AC Charge)],  PSP1 [1: Load-Battery-Utiliy]",
         "type": "SETTER",
         "response": [
@@ -343,7 +343,7 @@ COMMANDS = {
     "PEI": {
         "name": "PEI",
         "prefix": "^S006",
-        "description": "Set Machine type,  enable: Grid-Tie 			(Maunal Option 09)",
+        "description": "Set Machine type,  enable: Grid-Tie 			(Manual Option 09)",
         "help": " -- example: PEI 		(set enable Grid-Tie)",
         "type": "SETTER",
         "response": [
@@ -357,7 +357,7 @@ COMMANDS = {
     "PDI": {
         "name": "PDI",
         "prefix": "^S006",
-        "description": "Set Machine type, disable: Grid-Tie 			(Maunal Option 09)",
+        "description": "Set Machine type, disable: Grid-Tie 			(Manual Option 09)",
         "help": " -- example: PDI 		(set disable Grid-Tie)",
         "type": "SETTER",
         "response": [
@@ -371,7 +371,7 @@ COMMANDS = {
     "PCP": {
         "name": "PCP",
         "prefix": "^S009",
-        "description": "Set charging source priority 				(Maunal Option 10)",
+        "description": "Set charging source priority 				(Manual Option 10)",
         "help": " -- example: PCP0,1 		(set unit 0 [0-9] to 0: Solar first, 1: Solar and Utility, 2: Only solar)",
         "type": "SETTER",
         "response": [
@@ -386,7 +386,7 @@ COMMANDS = {
     "MCHGC": {
         "name": "MCHGC",
         "prefix": "^S013",
-        "description": "Set Battery Max Charging Current Solar + AC 		(Maunal Option 11)",
+        "description": "Set Battery Max Charging Current Solar + AC 		(Manual Option 11)",
         "help": " -- example: MCHGC0,030 	(set unit 0 [0-9] to max charging current of  30A [    010 020 030 040 050 060 070 080])",
         "type": "SETTER",
         "response": [
@@ -401,7 +401,7 @@ COMMANDS = {
     "MUCHGC": {
         "name": "MUCHGC",
         "prefix": "^S014",
-        "description": "Set Battery Max AC Charging Current 			(Maunal Option 13)",
+        "description": "Set Battery Max AC Charging Current 			(Manual Option 13)",
         "help": " -- example: MUCHGC0,030 	(set unit 0 [0-9] utility charging current to 30A [002 010 020 030 040 050 060 070 080])",
         "type": "SETTER",
         "response": [
@@ -415,7 +415,7 @@ COMMANDS = {
     "PBT": {
         "name": "PBT",
         "prefix": "^S007",
-        "description": "Set Battery Type 					(Maunal Option 14)",
+        "description": "Set Battery Type 					(Manual Option 14)",
         "help": " -- example: PBT0 		(set battery as PBT0 [0: AGM], PBT1 [1: FLOODED], PBT2 [2: USER])",
         "type": "SETTER",
         "response": [
@@ -430,7 +430,7 @@ COMMANDS = {
     "MCHGV": {
         "name": "MCHGV",
         "prefix": "^S015",
-        "description": "Set Battery Bulk,Float charge voltages 		     (Maunal Option 17,18)",
+        "description": "Set Battery Bulk,Float charge voltages 		     (Manual Option 17,18)",
         "help": " -- example: MCHGV552,540 	(set Bulk - CV voltage [480~584] in 0.1V xxx, Float voltage [480~584] in 0.1V yyy)",
         "type": "SETTER",
         "response": [
@@ -446,7 +446,7 @@ COMMANDS = {
     "PSDV": {
         "name": "PSDV",
         "prefix": "^S010",
-        "description": "Set Battery Cut-off Voltage	 			(Maunal Option 19)",
+        "description": "Set Battery Cut-off Voltage	 			(Manual Option 19)",
         "help": " -- example: PSDV450 		(set battery cut-off voltage to 45V [400~480V] for 48V unit)",
         "type": "SETTER",
         "response": [
@@ -461,8 +461,8 @@ COMMANDS = {
     "BUCD": {
         "name": "BUCD",
         "prefix": "^S014",
-        "description": "Set Battery Stop dis,charging when Grid is available (Maunal Option 20,21)",
-        "help": " -- example: BUCD44,48	(set Stop discharge Voltate [440~510] in 0.1V xxx, Stop Charge Voltage [000(Full) or 480~580] in 0.1V yyy)",
+        "description": "Set Battery Stop dis,charging when Grid is available (Manual Option 20,21)",
+        "help": " -- example: BUCD440,480	(set Stop discharge Voltage [440~510] in 0.1V xxx, Stop Charge Voltage [000(Full) or 480~580] in 0.1V yyy)",
         "type": "SETTER",
         "response": [
             ["ack", "Command execution", {"NAK": "Failed", "ACK": "Successful"}]
@@ -471,7 +471,7 @@ COMMANDS = {
             b"(NAK\x73\x73\r",
             b"(ACK\x39\x20\r",
         ],
-        "regex": "BUCD(4[4-9]0|5[0-1]0,000|4[8-9]0|5[0-8]0)$",
+        "regex": "BUCD((4[4-9]0|5[0-1]0),(000|4[8-9]0|5[0-8]0))$",
     },
 }
 
@@ -510,7 +510,7 @@ class pi18(AbstractProtocol):
 
     def get_full_command(self, command) -> bytes:
         """
-        Override the default get_full_command as its different for PI18
+        Override the default get_full_command as its different
         """
         log.info(
             f"Using protocol {self._protocol_id} with {len(self.COMMANDS)} commands"
@@ -522,31 +522,40 @@ class pi18(AbstractProtocol):
         if self._command_defn is None:
             return None
 
+        # Full command components
         _cmd = bytes(self._command, "utf-8")
+        log.debug(f"_cmd is: {_cmd}")
+
         _type = self._command_defn["type"]
+        log.debug(f"_type is: {_type}")
 
-        # data_length = len(_cmd) + 2 + 1
+        # Hand coded prefix
+        _prefix = self._command_defn["prefix"]
+        log.debug(f"_prefix: {_prefix}")
+        # Auto determined prefix - TODO
+        data_length = len(_cmd) + 3
         if _type == "QUERY":
-            _prefix = self._command_defn["prefix"]
+            auto_prefix = f"^P{data_length:03}"
         elif _type == "SETTER":
-            _prefix = self._command_defn["prefix"]
-            #
-            # _prefix = f"^S{data_length:03}"
-
+            auto_prefix = f"^S{data_length:03}"
         else:
-            data_length = len(_cmd) + 2 + 1
-            _prefix = f"^P{data_length:03}"
+            log.info(f"No type defined for command {_cmd}")
+            auto_prefix = f"^P{data_length:03}"
+        log.debug(f"auto_prefix: {auto_prefix}")
 
         _pre_cmd = bytes(_prefix, "utf-8") + _cmd
-
+        # _pre_cmd = bytes(auto_prefix, "utf-8") + _cmd
         log.debug(f"_pre_cmd: {_pre_cmd}")
-        # calculate the CRC
-        crc_high, crc_low = crc(_pre_cmd)
-        # combine byte_cmd, CRC , return
-        # PI18 full command "^P005GS\x..\x..\r"
-        _crc = bytes([crc_high, crc_low, 13])
-        full_command = _pre_cmd + _crc
 
+        # For commands that dont need CRC
+        if "nocrc" in self._command_defn and self._command_defn["nocrc"] is True:
+            full_command = _pre_cmd + bytes([13])
+        # crc commands
+        else:
+            # calculate the CRC
+            crc_high, crc_low = crc(_pre_cmd)
+            # combine byte_cmd, CRC , return
+            full_command = _pre_cmd + bytes([crc_high, crc_low, 13])
         log.debug(f"full command: {full_command}")
         return full_command
 
@@ -558,6 +567,9 @@ class pi18(AbstractProtocol):
         if responses[0] == b"^0\x1b\xe3\r":
             # is a reject response
             return ["NAK"]
+        elif responses[0] == b"^1\x0b\xc2\r":
+            # is a successful acknowledgement response
+            return ["ACK"]
 
         # Drop ^Dxxx from first response
         responses[0] = responses[0][5:]
